@@ -4,7 +4,7 @@ Test the async routing backend.
 import json
 from unittest import TestCase
 
-from mock import sentinel, patch
+from unittest.mock import sentinel, patch
 from eventtracking.backends.async_routing import AsyncRoutingBackend
 
 
@@ -14,7 +14,7 @@ class TestAsyncRoutingBackend(TestCase):
     """
 
     def setUp(self):
-        super(TestAsyncRoutingBackend, self).setUp()
+        super().setUp()
         self.sample_event = {
             'name': str(sentinel.name),
             'event_type': 'edx.test.event',
