@@ -1,6 +1,5 @@
 """Filter out events whose names aren't on a pre-configured whitelist"""
 
-from __future__ import absolute_import
 
 from eventtracking.processors.exceptions import EventEmissionExit
 
@@ -19,11 +18,11 @@ class NameWhitelistProcessor:
                 raise TypeError
 
             self.whitelist = frozenset(whitelist)
-        except TypeError:
+        except TypeError as error:
             raise TypeError(
                 'The NameWhitelistProcessor must be passed a collection of allowed names '
                 'using the "whitelist" parameter'
-            )
+            ) from error
 
     def __call__(self, event):
         if event['name'] not in self.whitelist:
