@@ -16,11 +16,18 @@ logger = get_task_logger(__name__)
 @shared_task(name='eventtracking.tasks.send_event')
 def send_event(backend_name, json_event):
     """
-    Send event to configured backends asynchronously.
+    Send event to configured top-level backend asynchronously.
 
     Load the backend with name `backend_name` and use it to process and send
     the event to configured nested backends.
 
+    WARNING: Do not use this task directly! It is intended for use
+    only by the AsyncRoutingBackend, since it is implemented with the
+    following assumptions:
+
+    - That the top-level processors have already been run on the event
+    - That the named backend is a RoutingBackend (or descendent)
+
     Arguments:
         backend_name (str):    name of the backend to use
         json_event (str)  :    JSON encoded event
@@ -29,6 +36,13 @@ def send_event(backend_name, json_event):
     tracker = get_tracker()
     backend = tracker.backends[backend_name]
 
+    # Reimplements `RoutingBackend.send()` logic so that the event
+    # doesn't get sent via celery again.
+    #
+    # `AsyncRoutingBackend.send()` should probably be changed to add
+    # an `immediate=False` kwarg and call the super method to perform
+    # immediate processing when `immediate=True`.
+
     try:
         processed_event = backend.process_event(event)
         logger.info('Successfully processed event "{}"'.format(event['name']))
